function [WW,P] = init_tetro(num_cov)

% initialize the tetrolet transform

% INPUT
% num_cov - number of admissible tetromino coverings
%
% OUTPUT
% WW - sparse wavelet matrix of size (16*num_cov) x (16*num_cov)
%  P - permutation matrix of size (16 x num_cov)
%
%
%  2009-02-20 (jens.krommweh@uni-due.de)


global COVER_NUMSOL
global P % contains permutation
global W
global WW
global DEV % contains deviations of coverings
 
W1 = [1  1  1  1;
      1  1 -1 -1;
      1 -1  1 -1;
      1 -1 -1  1]; % WT matrix
W = 1/2*kron(eye(4),W1);

% ### optional restriction to certain tilings ###
if num_cov == 117
    x = load('mat117.mat');
    WW = x.WW;
    y = load('mat117P.mat');
    P = y.P;
elseif  num_cov == 64
    x = load('mat64.mat');
    WW = x.WW;
    y = load('mat64P.mat');
    P = y.P;
elseif num_cov == 32
    x = load('mat32.mat');
    WW = x.WW;
    y = load('mat32P.mat');
    P = y.P;
elseif num_cov == 16
    x = load('mat16.mat');
    WW = x.WW;
    y = load('mat16P.mat');
    P = y.P;
else % not reasonable -> computional expensive
    % i) generate matrix P
    A = zeros(4);
    P = zeros(16,117);
    COVER_NUMSOL = 0;
    DEV = zeros(1,117);
    tetromino_gen_sort(A);
    x1 = load('cover.mat');
    cov = x1.y1;
    P = P(:,cov(1:num_cov));
    dev = DEV(cov);
    [q,permu] = sort(dev(1:num_cov),'descend');
    P = P(:,permu);
    % ii) generate matrix WW   
    I2 = eye(numel(P));
    per = I2(P(:),:);
    I3 = eye(num_cov);
    WW = sparse(kron(I3,W)*per);
end