function [r,wave_min,permut] = opt_wave10rel(v,dis,rel1)

% INPUT:
% v: pixel vector of length 1872
% dis: distribution vector
% rel1: relaxing parameter

% OUTPUT:
% r: lowpass part (vector of length 4)
% wave_min: wavelets (vector of length 16 with at most 12 nonzero entries)
% permut: number of covering (1,...,117), necessary for reconstruction

global WW

sizeP = length(v)/16;

ma = reshape(WW*v,16,sizeP);
scf = ma([1 5 9 13],:); % store rows with scf coeff
ma([1 5 9 13],:) = [];   % delete scf coeff

% find column ind with minimal l_1-norm of wavelets
z1 = sum(abs(ma));
ind = find(z1 <= min(z1) + rel1); % find entries with minimal l_1-norm

z0 = sum(ma(:,ind) ~= 0);
rel0 = 2; % relaxing parameter
z10 = find(z0 <= min(z0) + rel0); % find among these the entry with minimal l_0-norm

z10 = find(dis(z10) == max(dis(z10))); % find among these the entry with maximal occurence

permut = ind(z10(1)); % choose entry with minimal l_1-norm (if more possibilities -> take first one)

wave_min = ma(:,permut); % wavelets
r = scf(:,permut); % scaling functions